package com;

import java.util.ArrayList;
import java.util.HashMap;

/**
 * The Airplane class representing an airplane that is on the airport with it's available seats and full seats
 *
 * @author Roham Zendehdel
 * @version 1.00, May 2019
 */
public class Airplane {
    private HashMap<Integer, Seat> seats;
    private HashMap<Integer, Seat> reservedSeats;
    private HashMap<Integer, Seat> emptySeats;
    private String type;

    public Airplane(String type) {
        this.type = type;
        this.seats = new HashMap<>();
        this.reservedSeats = new HashMap<>();
        this.emptySeats = new HashMap<>();
    }

    public String getType() {
        return type;
    }

    public void addSeat(Seat s) {
        this.seats.put(s.getNumber(), s);
        this.emptySeats.put(s.getNumber(), s);
    }

    /**
     * Getting the full list of the airplane's seats
     *
     * @return list of the airplane's seats
     */
    public HashMap<Integer, Seat> getSeats() {
        return this.seats;
    }

    /**
     * Reserving a seat thus making it unavailable
     *
     * @param s the seat that is going to be reserved
     * @return 0 if reservation was successful and -1 if it wasn't
     */
    public int reserveSeat(Seat s) {
        if (this.reservedSeats.get(s.getNumber()) == null) {
            this.reservedSeats.put(s.getNumber(), s);
            this.emptySeats.remove(s.getNumber(), s);
            return 0;
        } else return -1;
    }

    /**
     * Getting a list of the empty seats in the airplane
     *
     * @return list of empty seats
     */
    public HashMap<Integer, Seat> getEmptySeats() {
        return this.emptySeats;
    }

    /**
     * Getting a list of the reserved seats in the airplane
     *
     * @return list of reserved seats
     */
    public HashMap<Integer, Seat> getReservedSeats() {
        return this.reservedSeats;
    }
}
